summaryrefslogtreecommitdiff
path: root/indra/newview/llpanelprofilepicks.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llpanelprofilepicks.h')
-rw-r--r--indra/newview/llpanelprofilepicks.h9
1 files changed, 8 insertions, 1 deletions
diff --git a/indra/newview/llpanelprofilepicks.h b/indra/newview/llpanelprofilepicks.h
index d5df7b7f12..fc975604d9 100644
--- a/indra/newview/llpanelprofilepicks.h
+++ b/indra/newview/llpanelprofilepicks.h
@@ -207,10 +207,15 @@ protected:
void onClickSetLocation();
/**
* Callback for "Save" button click
*/
void onClickSave();
+ /**
+ * Callback for "Save" button click
+ */
+ void onClickCancel();
+
std::string getLocationNotice();
/**
@@ -225,6 +230,8 @@ protected:
LLTextEditor* mPickDescription;
LLButton* mSetCurrentLocationButton;
LLButton* mSaveButton;
+ LLButton* mCreateButton;
+ LLButton* mCancelButton;
LLVector3d mPosGlobal;
LLUUID mParcelId;
@@ -207,10 +207,15 @@ protected:
void onClickSetLocation();
/**
- * Callback for "Save" button click
+ * Callback for "Save" and "Create" button click
*/
void onClickSave();